==> downloads.html?file=gigkalender_v1.2.61_059.zip: gigkalender/guestbook/guestbook_show.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  if (IsUserAdmin()) { $UserIsAdmin = '1'; }
  else { $UserIsAdmin = '0'; }
    
  $EintraegeProSeite = getSetup('SetupGuestbookEntriesPerPage');
  $AnzahlEintraege = AnzahlEintraege();
  $AnzahlSeiten = ceil($AnzahlEintraege/$EintraegeProSeite);
  echo '<div id="GigKalender"><div class="Guestbook">';
  if ( $AnzahlEintraege!=0 ) // Einträge vorhanden
  {
    if ( isset($_REQUEST['page']) AND is_numeric( $_REQUEST['page'] ) ) { $aktuelleSeite = $_REQUEST['page']; }
    else { $aktuelleSeite=$AnzahlSeiten; }

    $obersterEintrag  = ($AnzahlSeiten-$aktuelleSeite)*$EintraegeProSeite;

    // Datensatz-Ausgabe festlegen
      $SQL_Befehl = "SELECT * FROM ".$prefix."guestbook order by Datum DESC LIMIT ".$obersterEintrag.", ".$EintraegeProSeite;
    // Saemtliche Datensatz-Ausgabe durchfuehren
      $resultat = mysql_db_query($db_name, $SQL_Befehl);

    echo GuestbookNavigation('Top');

    $aktuellerEintrag = $AnzahlEintraege-$obersterEintrag;

    while ( $row = mysql_fetch_array($resultat))
    {
      extract($row);
      echo '<div class="GuestbookEntry">
              <div class="GuestbookEntryHeadline">
                <span class="GuestbookEntryDate">'; 
      if ( $UserIsAdmin=='1' && $CODE!='' )
      { 
        echo '<span class="GuestbookErrorMessages">IP: '.$IP.'</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
        echo '<a href="'.$GigKalenderPath.'guestbook/guestbook_edit.php?code='.$CODE.'"><img src="'.PATH.'frontend/images/guestbook_edit.png" alt="'.$L_010.'" title="'.$L_010.'" /></a> ';
        echo '<a href="'.$GigKalenderPath.'guestbook/guestbook_delete.php?code='.$CODE.'"><img src="'.PATH.'frontend/images/guestbook_delete.png" alt="'.$L_009.'" title="'.$L_009.'" /></a> ';
      }
      echo '['.date($SetupFrontendGuestbookDateFormat, $Datum).']</span> '.$aktuellerEintrag.'. '.$Name.' ';
      if ($Ort!="") echo $L_152.' '.$Ort.' '; 
      echo '&nbsp;';
      if ($URL!="") echo ' <a href="'.$URL.'"><img src="'.PATH.'frontend/images/guestbook_url.png" alt="" /></a> ';

      $FormActionURL = getFrontendURL ( 'SetupGuestbookEmailURL' );
      if ($Email!="") echo '<form style="display:inline" id="form'.$GuestbookID.'" method="post" action="'.$FormActionURL.'">
                              <p style="display:inline">
                                <input type="hidden" name="page" value="mail" />
                                <input type="hidden" name="id" value="'.$GuestbookID.'" />
                                <a href="'.$FormActionURL.'" onclick="javascript:document.forms[\'form'.$GuestbookID.'\'].submit()"><img src="'.PATH.'frontend/images/guestbook_email.png" alt="" /></a>
                              </p>
                            </form>';

      if ($ICQ!="0" AND $ICQ!="") echo ' <a href="http://people.icq.com/people/about_me.php?uin='.$ICQ.'"><img src="'.PATH.'frontend/images/guestbook_icq.png" alt="" /></a> ';
      echo '</div>
          <div class="GuestbookEntryText">';
        $Nachricht = nl2br($Nachricht);
        echo $Nachricht;
        echo '
      </div>';
      if ($Kommentar!="")
      {
        echo '
          <div class="GuestbookEntryComment">
            '.$L_138.': ';
        $Kommentar =  nl2br($Kommentar);
        echo $Kommentar;
        echo '
          </div>
        ';
      }
      echo '
        </div>
      ';
      $aktuellerEintrag--;
    }
    echo GuestbookNavigation('Bottom');
  }
  else // Keine Einträge vorhanden
  {
    echo $L_144.'<br /><br />';
    echo '[ <a href="'.$_SERVER['PHP_SELF'].'?page=add"><img src="'.PATH.'frontend/images/guestbook_add.png" alt="" /></a> <a href="'.$_SERVER['PHP_SELF'].'?page=add">'.$L_112.'</a> ]';
  }
  echo '</div></div>';
?>

==> downloads.html?file=gigkalender_v1.2.64_009.zip: gigkalender/guestbook/guestbook_show.php <==
<?php
/*
    CREATIVE COMMONS - Attribution-No Derivative Works 3.0 Germany:
    - You may not alter, transform, or build upon this work.
    - Dieses Werk darf nicht bearbeitet oder in anderer Weise verändert werden.
*/
  if (IsUserAdmin()) { $UserIsAdmin = '1'; }
  else { $UserIsAdmin = '0'; }
    
  $EintraegeProSeite = getSetup('SetupGuestbookEntriesPerPage');
  $AnzahlEintraege = AnzahlEintraege();
  $AnzahlSeiten = ceil($AnzahlEintraege/$EintraegeProSeite);
  echo '<div class="GigKalender"><div class="Guestbook">';
  if ( $AnzahlEintraege!=0 ) // Einträge vorhanden
  {
    if ( isset($_REQUEST['page']) AND is_numeric( $_REQUEST['page'] ) ) { $aktuelleSeite = $_REQUEST['page']; }
    else { $aktuelleSeite=$AnzahlSeiten; }

    $obersterEintrag  = ($AnzahlSeiten-$aktuelleSeite)*$EintraegeProSeite;

    // Datensatz-Ausgabe festlegen
      $SQL_Befehl = "SELECT * FROM ".$prefix."guestbook order by Datum DESC LIMIT ".$obersterEintrag.", ".$EintraegeProSeite;
    // Saemtliche Datensatz-Ausgabe durchfuehren
      $resultat = mysql_db_query($db_name, $SQL_Befehl);

    echo GuestbookNavigation('Top');

    $aktuellerEintrag = $AnzahlEintraege-$obersterEintrag;

    while ( $row = mysql_fetch_array($resultat))
    {
      extract($row);
      echo '<div class="GuestbookEntry">
              <div class="GuestbookEntryHeadline">
                <span class="GuestbookEntryDate">'; 
      if ( $UserIsAdmin=='1' && $CODE!='' )
      { 
        echo '<span class="ErrorMessage">IP: '.$IP.'</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
        echo '<a href="'.$GigKalenderPath.'guestbook/guestbook_edit.php?code='.$CODE.'"><img src="'.PATH.'frontend/images/guestbook_edit.png" alt="'.$L_010.'" title="'.$L_010.'" /></a> ';
        echo '<a href="'.$GigKalenderPath.'guestbook/guestbook_delete.php?code='.$CODE.'"><img src="'.PATH.'frontend/images/guestbook_delete.png" alt="'.$L_009.'" title="'.$L_009.'" /></a> ';
      }
      echo '['.date($SetupFrontendGuestbookDateFormat, $Datum).']</span> '.$aktuellerEintrag.'. '.$Name.' ';
      if ($Ort!="") echo $L_152.' '.$Ort.' '; 
      echo '&nbsp;';
      if ($URL!="") echo ' <a href="'.$URL.'"><img src="'.PATH.'frontend/images/guestbook_url.png" alt="" /></a> ';

      $FormActionURL = getFrontendURL ( 'SetupGuestbookEmailURL' );
      if ($Email!="") echo '<form style="display:inline" id="form'.$GuestbookID.'" method="post" action="'.$FormActionURL.'" accept-charset="UTF-8">
                              <p style="display:inline">
                                <input type="hidden" name="page" value="mail" />
                                <input type="hidden" name="id" value="'.$GuestbookID.'" />
                                <a href="'.$FormActionURL.'" onclick="javascript:document.forms[\'form'.$GuestbookID.'\'].submit()"><img src="'.PATH.'frontend/images/guestbook_email.png" alt="" /></a>
                              </p>
                            </form>';

      if ($ICQ!="0" AND $ICQ!="") echo ' <a href="http://people.icq.com/people/about_me.php?uin='.$ICQ.'"><img src="'.PATH.'frontend/images/guestbook_icq.png" alt="" /></a> ';
      echo '</div>
          <div class="GuestbookEntryText">';
        $Nachricht = nl2br($Nachricht);
        echo $Nachricht;
        echo '
      </div>';
      if ($Kommentar!="")
      {
        echo '
          <div class="GuestbookEntryComment">
            '.$L_138.': ';
        $Kommentar =  nl2br($Kommentar);
        echo $Kommentar;
        echo '
          </div>
        ';
      }
      echo '
        </div>
      ';
      $aktuellerEintrag--;
    }
    echo GuestbookNavigation('Bottom');
  }
  else // Keine Einträge vorhanden
  {
    // URL bestimmen
      if ( $SetupGuestbookFormURL=='' )
      {
        if (isset($_SERVER['REDIRECT_URL'])) $REDIRECT_URL = $_SERVER['REDIRECT_URL'];
          else $REDIRECT_URL = '';
        $URL = $REDIRECT_URL.'?page=add';
      }
      else $URL = $SetupGuestbookFormURL;
      $URL = str_replace("&","&amp;",$URL);
    echo $L_144.'<br /><br />';
    echo '[ <a href="'.$URL.'"><img src="'.PATH.'frontend/images/guestbook_add.png" alt="" /></a> <a href="'.$URL.'">'.$L_112.'</a> ]';
  }
  echo '</div></div>';
?>
